Package: hellodatascience
Type: Package
Title: Datasets from the Hello Data Science Book
Version: 0.1.1
Authors@R: c(
    person("Mine", "Dogucu", , "mdogucu@gmail.com", c("aut", "cre"), comment = c(ORCID = "0000-0002-8007-934X")), 
    person("Catalina", "Medina", , role = "aut", comment = c(ORCID = "0000-0003-2847-8180")),
    person("Alma", "Castro", , role = "aut")
    )
Description: Provides datasets used for analysis 
  and visualizations in the open-access Hello Data Science book. 
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5)
URL: https://hellodata-science.github.io/hellodatascience/
BugReports: https://github.com/hellodata-science/hellodatascience/issues
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-12 17:13:57 UTC; minedogucu
Author: Mine Dogucu [aut, cre] (ORCID: <https://orcid.org/0000-0002-8007-934X>),
  Catalina Medina [aut] (ORCID: <https://orcid.org/0000-0003-2847-8180>),
  Alma Castro [aut]
Maintainer: Mine Dogucu <mdogucu@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-12 17:50:02 UTC
Built: R 4.6.0; ; 2026-06-12 21:21:50 UTC; unix
