
# hellodatascience

📦 R package for Supplemental Materials for the Hello Data Science Book

<!-- README.md is generated from README.Rmd. Please edit that file -->

# hellodatascience <img src="man/figures/logo.png" align="right" alt="a hex shaped logo with green, pink, and yellow scatterplot points in the background. There is text that reads Hello Data Science" width="120" />

**hellodatascience** is a package to supplement the upcoming open-access
*Hello Data Science* book. It contains datasets that are used in the
book. You can find documentation on the [package
website](https://hellodata-science.github.io/hellodatascience/).

<hr>

## Installation

You can install `hellodatascience` from CRAN.

``` r
install.packages("hellodatascience") 
```

You can install the development version from GitHub. You would also need
to install the devtools package if you do not have it installed already.

``` r
#install.packages("devtools") 
devtools::install_github("hellodata-science/hellodatascience")
```
